==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/pl/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informacje</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>Ustawienia </strong> i Konfiguracja',
  '<strong>User</strong> administration' => 'Zarządzanie <strong>Użytkownikiem</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => 'Akceptuj użytkownika: <strong>{displayName}</strong>',
  'Account' => 'Konto',
  'Account Request for \'{displayName}\' has been approved.' => 'Konto dla \'{displayName}\' zostało zaakceptowane.',
  'Account Request for \'{displayName}\' has been declined.' => 'Konto dla \'{displayName}\' nie zostało zaakceptowane.',
  'Actions' => 'Akcje',
  'Active users' => 'Aktywni użytkownicy',
  'Add Groups...' => 'Dodaj Grupy...',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => 'Dodaj nową kategorię',
  'Add new field' => 'Dodaj nowe pole',
  'Add new group' => 'Dodaj nową grupę',
  'Add new members...' => 'Dodaj nowych członków...',
  'Add new user' => 'Dodaj nowego użytkownika',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => 'Wszystkie prywatne dane tego użytkownika zostaną nieodwracalnie usunięte.',
  'Allow' => 'Zezwól',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Zezwól na ograniczony dostęp dla niezalogowanych użytkowników (gości)',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => 'Na pewno chcesz wyłączyć tego użytkownika?',
  'Are you really sure that you want to enable this user?' => 'Na pewno chcesz włączyć tego użytkownika?',
  'Are you really sure that you want to impersonate this user?' => 'Na pewno chcesz użyć tożsamości tego użytkownika?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => 'Na pewno chcesz usunąć danego użytkownika?',
  'Cancel' => 'Anuluj',
  'Click here to review' => 'Kliknij tutaj aby przejrzeć',
  'Confirm user deletion' => 'Potwierdź usunięcie użytkownika',
  'Could not load category.' => 'Nie można wczytać kategorii.',
  'Create new group' => 'Utwórz nową grupę',
  'Create new profile category' => 'Utwórz profil nowej kategorii',
  'Create new profile field' => 'Utwórz profil nowego pola',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Odrzuć i usuń użytkownika: <strong>{displayName}</strong>',
  'Default' => 'Domyślna',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => 'Domyślna zawartość wiadomości akceptacyjnej po rejestracji',
  'Default content of the registration denial email' => 'Domyślna zawartość wiadomości odrzucającej po rejestracji',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Domyślny czas bezczynności użytkownika, po którym zostanie wylogowany ( w sekundach, opcjonalnie)',
  'Default user profile visibility' => 'Domyślna widoczność profilu użytkownika',
  'Delete' => 'Usuń',
  'Delete All' => '',
  'Delete all contributions of this user' => 'Usuń wszystkie działania użytkownika',
  'Delete invitation' => 'Usuń zaproszenie',
  'Delete invitation?' => 'Usunąć zaproszenie?',
  'Delete spaces which are owned by this user' => 'Usuń strefy w posiadaniu tego użytkownika',
  'Deleted invitation' => 'Usunięto zaproszenie',
  'Deleted users' => 'Usuń użytkowników',
  'Disable' => 'Wyłącz',
  'Disabled' => 'Wyłączony',
  'Disabled users' => 'Nieaktywni użytkownicy',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Nie zmieniaj przykładowych wpisów jak {displayName}  jeżeli chcesz żeby zostały wypełnione automatycznie przez system. Aby wyzerować zawartość pól email  na domyślne, pozostaw je puste.',
  'Edit category' => 'Edytuj kategorie',
  'Edit profile category' => 'Edytuj profil kategorii',
  'Edit profile field' => 'Edytuj profil pola',
  'Edit user: {name}' => 'Edytuj użytkownika: {name}',
  'Enable' => 'Włącz',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Włączony',
  'Group Manager' => 'Zarządca Grupy',
  'Group not found!' => 'Nie znaleziono grupy!',
  'Group user not found!' => 'Użytkownik grupy nie znaleziony!',
  'Groups' => 'Grupy',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => 'Witaj {displayName},<br><br> Twoje konto zostało aktywowane.<br><br> Kliknij tutaj aby się zalogować:<br> {loginLink}<br><br> Pozdrawiam<br> {AdminName}<br><br>',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => 'Witaj {displayName},<br><br> Twoje prośba o założenie konta została odrzzucona.<br><br> Pozdrawiam<br> {AdminName}<br><br>',
  'Here you can create or edit profile categories and fields.' => 'Tutaj możesz tworzyć i edytowac profile kategorii i pól.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Jeżeli ta opcja nie jest wybrana, własność stref zostanie przekazana na Twoje konto.',
  'Impersonate' => 'Użyj tożsamości',
  'Include captcha in registration form' => 'Dołącz captcha w formularzu rejestracji',
  'Invite not found!' => 'Nie znaleziono zaproszenia!',
  'Last login' => 'Ostatnio zalogowany',
  'List pending registrations' => 'Lista oczekujących rejestracji',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'Zarządzaj grupą: {groupName}',
  'Manage groups' => 'Zarządzaj grupami',
  'Manage profile attributes' => 'Zarządzaj atrybutami profilu',
  'Member since' => 'Członek od',
  'Members' => 'Członkowie',
  'Members can invite external users by email' => 'Członkowie mogą zapraszać zewnętrznych użytkowników za pomocą emalia',
  'Message' => 'Wiadomość',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Minimalna wartość to 20 sekund. Jeśli puste, sesja zakończy się po 1400 sekundach (24 minuty) bez względu na aktywność.',
  'New approval requests' => 'Nowe żądania zatwierdzenia',
  'New users can register' => 'Anonimowi użytkownicy mogą rejestrować się',
  'No' => 'Nie',
  'No value found!' => 'Nie znaleziono wartości!',
  'One or more user needs your approval as group admin.' => 'Jeden lub więcej użytkowników wymaga zatwierdzenia przez grupę administratorów.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Właściwe tylko dla ograniczonego dostępu dla niezarejestrowanych użytkowników. Dotyczy jedynie nowych użytkowników.',
  'Overview' => 'Przegląd',
  'Password' => 'Hasło',
  'Pending approvals' => 'Oczekujące do zatwierdzenia',
  'Pending user approvals' => 'Użytkownicy oczekujący na zaakceptowanie',
  'Permanently delete' => 'Usuń na stałe',
  'Permissions' => 'Pozwolenia',
  'Profile Permissions' => '',
  'Profiles' => 'Profile',
  'Remove from group' => 'Usuń z grupy',
  'Require group admin approval after registration' => 'Wymagaj zatwierdzenia po rejestracji przez administratora grupy',
  'Resend invitation email' => 'Wyślij ponownie wiadomość z zaproszeniem',
  'Save' => 'Zapisz',
  'Search by name, email or id.' => 'Szukaj po nazwie, e-mailu lub id.',
  'Select Groups' => 'Wybierz Grupy',
  'Send & save' => 'Wyślij i zapisz',
  'Send invitation email' => 'Wyślij wiadomość z zaproszeniem',
  'Send invitation email again?' => 'Wysłać ponownie wiadomość z zaproszeniem?',
  'Send invite' => 'Wyślij zaproszenie',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Ustawienia',
  'Show group selection at registration' => '',
  'Subject' => 'Temat',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => 'Poniższa lista zawiera wszystkie oczekujące zapisy i zaproszenia.',
  'The following list contains all registered users awaiting an approval.' => 'Poniższa lista zawiera wszystkich zarejestrowanych użytkowników oczekujących na akceptacje.',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => 'Ten użytkownik jest właścicielem tych stref:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Ten przegląd zawiera listę wszystkich zarejestrowanych użytkowników z możliwością przeglądania, edycji i usuwania użytkowników.',
  'This user owns no spaces.' => 'Ten użytkownik nie jest właścicielem żadnych stref.',
  'Unapproved' => 'Niezatwierdzony',
  'User deletion process queued.' => 'Usunięcie użytkownika dodane do kolejki.',
  'User is already a member of this group.' => 'Użytkownik już jest członkiem tej grupy!',
  'User not found!' => 'Użytkownik nie znaleziony!',
  'Users' => 'Użytkownicy',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Użytkownicy mogą zostać przydzieleni do innych grup (np. drużyn, działów itp.) z ustalonymi standardowymi  strefami, grupami i pozwoleniami.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Używając tej opcji cały wkład (t.j. wpisy, komentarze lub polubienia) tego użytkownika zostanie nieodwracalnie usunięty.',
  'View profile' => 'Zobacz profil',
  'Visible for members only' => 'Widoczne tylko dla członków',
  'Visible for members+guests' => 'Widoczne dla członków i gości',
  'Yes' => 'Tak',
  'You can only delete empty categories!' => 'Możesz usunąć tylko pustą kategorię!',
  'You cannot delete yourself!' => 'Nie możesz się usunąć!',
  'never' => 'nigdy',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/pl/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informacje</strong>',
  '<strong>Profile</strong> Permissions' => 'Uprawnienia <strong>Profilu</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Ustawienia </strong> i Konfiguracja',
  '<strong>User</strong> administration' => 'Zarządzanie <strong>Użytkownikiem</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Ostrzeżenie:</strong> Wszystkie indywidualne profilowe ustawienia pozwoleń zostaną przywrócone do domyślnych wartości!',
  'Accept user: <strong>{displayName}</strong> ' => 'Akceptuj użytkownika: <strong>{displayName}</strong>',
  'Account' => 'Konto',
  'Account Request for \'{displayName}\' has been approved.' => 'Konto dla \'{displayName}\' zostało zaakceptowane.',
  'Account Request for \'{displayName}\' has been declined.' => 'Konto dla \'{displayName}\' nie zostało zaakceptowane.',
  'Actions' => 'Akcje',
  'Active users' => 'Aktywni użytkownicy',
  'Add Groups...' => 'Dodaj Grupy...',
  'Add new category' => 'Dodaj nową kategorię',
  'Add new field' => 'Dodaj nowe pole',
  'Add new group' => 'Dodaj nową grupę',
  'Add new members...' => 'Dodaj nowych członków...',
  'Add new user' => 'Dodaj nowego użytkownika',
  'Administrator group could not be deleted!' => 'Administrator grupy nie może zostać usunięty!',
  'All open registration invitations were successfully deleted.' => 'Wszystkie otwarte zaproszenia do rejestracji zostały poprawnie usunięte.',
  'All the personal data of this user will be irrevocably deleted.' => 'Wszystkie prywatne dane tego użytkownika zostaną nieodwracalnie usunięte.',
  'Allow' => 'Zezwól',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => 'Czy zezwolić użytkownikom na ustawianie indywidualnych pozwoleń w profilu?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Zezwól na ograniczony dostęp dla niezalogowanych użytkowników (gości)',
  'Applied to new or existing users without any other group membership.' => 'Ma zastosowanie dla nowych lub istniejących użytkowników bez żadnej grupy lub członkowstwa.',
  'Are you really sure that you want to disable this user?' => 'Na pewno chcesz wyłączyć tego użytkownika?',
  'Are you really sure that you want to enable this user?' => 'Na pewno chcesz włączyć tego użytkownika?',
  'Are you really sure that you want to impersonate this user?' => 'Na pewno chcesz użyć tożsamości tego użytkownika?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Czy jesteś pewien? Użytkownicy którzy nie są przypisani do innej grupy zostaną automatycznie przypisani do domyślnej grupy.',
  'Are you sure that you want to delete following user?' => 'Na pewno chcesz usunąć danego użytkownika?',
  'Cancel' => 'Anuluj',
  'Click here to review' => 'Kliknij tutaj aby przejrzeć',
  'Confirm user deletion' => 'Potwierdź usunięcie użytkownika',
  'Could not load category.' => 'Nie można wczytać kategorii.',
  'Create new group' => 'Utwórz nową grupę',
  'Create new profile category' => 'Utwórz profil nowej kategorii',
  'Create new profile field' => 'Utwórz profil nowego pola',
  'Deactivate' => 'Dezaktywuj',
  'Deactivate individual profile permissions?' => 'Dezaktywować indywidualne pozwolenia profilowe?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Odrzuć i usuń użytkownika: <strong>{displayName}</strong>',
  'Default' => 'Domyślna',
  'Default Profile Permissions' => 'Domyślne Pozwolenia Profilowe',
  'Default Sorting' => '',
  'Default content of the registration approval email' => 'Domyślna zawartość wiadomości akceptacyjnej po rejestracji',
  'Default content of the registration denial email' => 'Domyślna zawartość wiadomości odrzucającej po rejestracji',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Domyślny czas bezczynności użytkownika, po którym zostanie wylogowany ( w sekundach, opcjonalnie)',
  'Default user profile visibility' => 'Domyślna widoczność profilu użytkownika',
  'Delete' => 'Usuń',
  'Delete All' => 'Usuń Wszystkie',
  'Delete all contributions of this user' => 'Usuń wszystkie działania użytkownika',
  'Delete invitation' => 'Usuń zaproszenie',
  'Delete invitation?' => 'Usunąć zaproszenie?',
  'Delete spaces which are owned by this user' => 'Usuń strefy w posiadaniu tego użytkownika',
  'Deleted invitation' => 'Usunięto zaproszenie',
  'Deleted users' => 'Usuń użytkowników',
  'Disable' => 'Wyłącz',
  'Disabled' => 'Wyłączony',
  'Disabled users' => 'Nieaktywni użytkownicy',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Nie zmieniaj przykładowych wpisów jak {displayName}  jeżeli chcesz żeby zostały wypełnione automatycznie przez system. Aby wyzerować zawartość pól email  na domyślne, pozostaw je puste.',
  'Edit category' => 'Edytuj kategorie',
  'Edit profile category' => 'Edytuj profil kategorii',
  'Edit profile field' => 'Edytuj profil pola',
  'Edit user: {name}' => 'Edytuj użytkownika: {name}',
  'Enable' => 'Włącz',
  'Enable individual profile permissions' => 'Włącz indywidualne pozwolenia profilowe',
  'Enabled' => 'Włączony',
  'First name' => 'Imię',
  'Group Manager' => 'Zarządca Grupy',
  'Group not found!' => 'Nie znaleziono grupy!',
  'Group user not found!' => 'Użytkownik grupy nie znaleziony!',
  'Groups' => 'Grupy',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => 'Tutaj możesz tworzyć i edytowac profile kategorii i pól.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Jeśli indywidualne pozwolenia profilowe są wyłączone, następujące ustawienia są niezmienne dla wszystkich użytkowników. Jeśli indywidualne ustawienia profilowe są zezwolone, te ustawienia są ustawione jako domyślne i użytkownik może je edytować. Następujące wpisy są wtedy wyświetlone w tej samej formie w ustawieniach profilu użytkownika.',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Jeżeli ta opcja nie jest wybrana, własność stref zostanie przekazana na Twoje konto.',
  'Impersonate' => 'Użyj tożsamości',
  'Include captcha in registration form' => 'Dołącz captcha w formularzu rejestracji',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => 'Nie znaleziono zaproszenia!',
  'Last login' => 'Ostatnio zalogowany',
  'Last name' => 'Nazwisko',
  'List pending registrations' => 'Lista oczekujących rejestracji',
  'Make the group selectable at registration.' => 'Daj możliwość zaznaczenia grupy w trakcie rejestracji.',
  'Manage group: {groupName}' => 'Zarządzaj grupą: {groupName}',
  'Manage groups' => 'Zarządzaj grupami',
  'Manage profile attributes' => 'Zarządzaj atrybutami profilu',
  'Member since' => 'Członek od',
  'Members' => 'Członkowie',
  'Members can invite external users by email' => 'Członkowie mogą zapraszać zewnętrznych użytkowników za pomocą emalia',
  'Message' => 'Wiadomość',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Minimalna wartość to 20 sekund. Jeśli puste, sesja zakończy się po 1400 sekundach (24 minuty) bez względu na aktywność.',
  'New approval requests' => 'Nowe żądania zatwierdzenia',
  'New users can register' => 'Anonimowi użytkownicy mogą rejestrować się',
  'No' => 'Nie',
  'No value found!' => 'Nie znaleziono wartości!',
  'None' => 'Brak',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => 'Jeden lub więcej użytkowników wymaga zatwierdzenia przez grupę administratorów.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Właściwe tylko dla ograniczonego dostępu dla niezarejestrowanych użytkowników. Dotyczy jedynie nowych użytkowników.',
  'Overview' => 'Przegląd',
  'Password' => 'Hasło',
  'Pending approvals' => 'Oczekujące do zatwierdzenia',
  'Pending user approvals' => 'Użytkownicy oczekujący na zaakceptowanie',
  'People' => 'Ludzie',
  'Permanently delete' => 'Usuń na stałe',
  'Permissions' => 'Pozwolenia',
  'Prioritised User Group' => '',
  'Profile Permissions' => 'Pozwolenia Profilowe',
  'Profiles' => 'Profile',
  'Protected' => 'Chroniona',
  'Protected group can not be deleted!' => '',
  'Remove from group' => 'Usuń z grupy',
  'Require group admin approval after registration' => 'Wymagaj zatwierdzenia po rejestracji przez administratora grupy',
  'Resend invitation email' => 'Wyślij ponownie wiadomość z zaproszeniem',
  'Save' => 'Zapisz',
  'Search by name, email or id.' => 'Szukaj po nazwie, e-mailu lub id.',
  'Select Groups' => 'Wybierz Grupy',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => 'Wyślij i odrzuć',
  'Send & save' => 'Wyślij i zapisz',
  'Send invitation email' => 'Wyślij wiadomość z zaproszeniem',
  'Send invitation email again?' => 'Wysłać ponownie wiadomość z zaproszeniem?',
  'Send invite' => 'Wyślij zaproszenie',
  'Send notifications to users when added to or removed from the group.' => 'Wysyłaj powiadomienia do użytkowników w przypadku dodania lub usunięcia z grupy.',
  'Settings' => 'Ustawienia',
  'Show group selection at registration' => 'Pokaż wybór grupy podczas rejestracji.',
  'Subject' => 'Temat',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Członkowstwo strefy wszystkich członków grupy zostanie zaktualizowane. Ta operacja może potrwać kilka minut.',
  'The following list contains all pending sign-ups and invites.' => 'Poniższa lista zawiera wszystkie oczekujące zapisy i zaproszenia.',
  'The following list contains all registered users awaiting an approval.' => 'Poniższa lista zawiera wszystkich zarejestrowanych użytkowników oczekujących na akceptacje.',
  'The selected invitations have been successfully deleted!' => 'Wybrane zaproszenia zostały pomyślnie usunięte!',
  'The user is the owner of these spaces:' => 'Ten użytkownik jest właścicielem tych stref:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Ta opcja pozwala ustalić czy użytkownicy mogą ustawiać indywidualne pozwolenia we własnych profilach.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Ten przegląd zawiera listę wszystkich zarejestrowanych użytkowników z możliwością przeglądania, edycji i usuwania użytkowników.',
  'This user owns no spaces.' => 'Ten użytkownik nie jest właścicielem żadnych stref.',
  'Unapproved' => 'Niezatwierdzony',
  'User deletion process queued.' => 'Usunięcie użytkownika dodane do kolejki.',
  'User is already a member of this group.' => 'Użytkownik już jest członkiem tej grupy!',
  'User not found!' => 'Użytkownik nie znaleziony!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Użytkownicy mogą zostać przydzieleni do innych grup (np. drużyn, działów itp.) z ustalonymi standardowymi  strefami, grupami i pozwoleniami.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Używając tej opcji cały wkład (t.j. wpisy, komentarze lub polubienia) tego użytkownika zostanie nieodwracalnie usunięty.',
  'View profile' => 'Zobacz profil',
  'Visible for members only' => 'Widoczne tylko dla członków',
  'Visible for members+guests' => 'Widoczne dla członków i gości',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => 'Tak',
  'You can only delete empty categories!' => 'Możesz usunąć tylko pustą kategorię!',
  'You cannot delete yourself!' => 'Nie możesz się usunąć!',
  'never' => 'nigdy',
);
